package com.xinelu.manage.mapper.taskpartitiondict;

import com.xinelu.manage.domain.taskpartitiondict.TaskPartitionDict;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 任务细分字典Mapper接口
 *
 * @author xinelu
 * @date 2024-03-11
 */
public interface TaskPartitionDictMapper {
    /**
     * 查询任务细分字典
     *
     * @param id 任务细分字典主键
     * @return 任务细分字典
     */
    TaskPartitionDict selectTaskPartitionDictById(Long id);

    /**
     * 查询任务细分字典列表
     *
     * @param taskPartitionDict 任务细分字典
     * @return 任务细分字典集合
     */
    List<TaskPartitionDict> selectTaskPartitionDictList(TaskPartitionDict taskPartitionDict);

    /**
     * 新增任务细分字典
     *
     * @param taskPartitionDict 任务细分字典
     * @return 结果
     */
    int insertTaskPartitionDict(TaskPartitionDict taskPartitionDict);

    /**
     * 修改任务细分字典
     *
     * @param taskPartitionDict 任务细分字典
     * @return 结果
     */
    int updateTaskPartitionDict(TaskPartitionDict taskPartitionDict);

    /**
     * 删除任务细分字典
     *
     * @param id 任务细分字典主键
     * @return 结果
     */
    int deleteTaskPartitionDictById(Long id);

    /**
     * 批量删除任务细分字典
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteTaskPartitionDictByIds(Long[] ids);

    List<TaskPartitionDict> selectTaskPartitionList( List<Long> ids);
}
